translate.storage.benchmark.TranslateBenchmarker

Package translate :: Package storage :: Module benchmark :: Class TranslateBenchmarker |
[hide private]
[frames] | no frames]

# Class TranslateBenchmarker

source code

class to aid in benchmarking Translate Toolkit stores

Instance Methods | [hide private]
__init__(self, test_dir, storeclass) sets up benchmarking on the test directory | source code
clear_test_dir(self) removes the given directory | source code
create_sample_files(self, num_dirs, files_per_dir, strings_per_file, source_words_per_string, target_words_per_string) creates sample files for benchmarking | source code
parse_file(self) parses all the files in the test directory into memory | source code